// Simple Consoleapplication to generate a html-File with statistics about
// the use of a publishingpoint on a Windows Media Server (v.9.0)
// by Andr Helbig (software@thamthon.de)
// v1.0 07.05.06


using System;
using System.Collections.Generic;
using System.Text;
using Microsoft.WindowsMediaServices.Interop;
using System.Runtime.InteropServices;
using System.IO;

namespace pubstats
{
    class Program
    {

        static void Main(string[] args)
        {

            string htmfile = "";
            string datafile = "";
            string publishingpoint = "Beispielpublishingpoint";
            bool bail = false;

            #region args
            for (int i = 0; i < args.Length; i++)
            {
                switch (args[i])
                {
                    case "/?":

                        usage();
                        bail = true;
                        break;
                    case "-p":
                        if (i < args.Length - 1)
                        {
                            publishingpoint = args[++i];
                        }
                        else
                        {
                            usage();
                            bail = true;
                        }
                        break;
                    case "-h":
                        if (i < args.Length - 1)
                        {
                            htmfile = args[++i];
                        }
                        else
                        {
                            usage();
                            bail = true;
                        }
                        break;

                    case "-d":
                        if (i < args.Length - 1)
                        {
                            datafile = args[++i];
                        }
                        else
                        {
                            usage();
                            bail = true;
                        }
                        break;

                    default:
                        usage();
                        bail = true;
                        break;
                }
            }
            #endregion

            //Args ok?
            if (bail == false)
            {

                Console.WriteLine("Publishingpoint:" + publishingpoint);
                Console.WriteLine("HtmlFile: " + htmfile);
                Console.WriteLine("DataFile: " + datafile);

                try
                {
                    // Create a WMSServer object.
                    WMSServer Server = new WMSServerClass();


                    IWMSPublishingPoints PubPoints;
                    IWMSPublishingPoint PubPoint;

                    // Get Information from all Publishingpoints
                    PubPoints = Server.PublishingPoints;

                    if (htmfile == "")
                    {
                        for (int i = 0; i < PubPoints.Count; i++)
                        {
                            PubPoint = PubPoints[i];

                            if (PubPoint.Name == publishingpoint)
                            {                           
                                //Print Results at Console
                                Console.WriteLine("Players connected at " + PubPoint.Name + ": " + PubPoint.Players.Count + " at " + DateTime.Now.ToString());
                                Console.WriteLine("Peak: " + PubPoint.Players.Count + " (since " + PubPoint.PeakCounters.CountersStartTime.ToString() + ")");
                            }
                        }
                    }
                    else
                    {

                        StreamWriter htm = File.CreateText(htmfile);

                        htm.WriteLine("<HTML>");
                        htm.WriteLine("<HEAD>");
                        htm.WriteLine("</HEAD>");
                        htm.WriteLine("<BODY>");
                        htm.WriteLine("<H2> Stats for publishingpoint " + publishingpoint + "</H>");
                        htm.WriteLine("<table border=\"1\"><tr>");
                        htm.WriteLine("<th>Time</th><th>Now Connected</th><th>Max connected</th></tr><tr>");


                        // Retrieve information about each publishing point.
                        for (int i = 0; i < PubPoints.Count; i++)
                        {
                            PubPoint = PubPoints[i];

                            if (PubPoint.Name == publishingpoint)
                            {
                                //Save data
                                if (!(datafile == ""))
                                {
                                    StreamWriter conf = File.AppendText(datafile);
                                    conf.WriteLine(DateTime.Now.ToString() + ";" + PubPoint.Players.Count + ";" + PubPoint.PeakCounters.ConnectedPlayers + ";" + PubPoint.PeakCounters.CountersStartTime.ToString());
                                    conf.Close();
                                }

                                //Print Results at Console
                                Console.WriteLine("Players connected at " + PubPoint.Name + ": " + PubPoint.Players.Count + " at " + DateTime.Now.ToString());
                                Console.WriteLine("Peak: " + PubPoint.Players.Count + " (since " + PubPoint.PeakCounters.CountersStartTime.ToString() + ")");
                                
                                //Write html-File
                                htm.WriteLine("<tr>");
                                htm.WriteLine("<th>" + DateTime.Now.ToString() + "</th");
                                htm.WriteLine("<th align=\"right\">" + PubPoint.Players.Count + "</th>");
                                htm.WriteLine("<th align=\"right\">" + PubPoint.PeakCounters.ConnectedPlayers + " (seit " + PubPoint.PeakCounters.CountersStartTime.ToString() + ")" + "</th>");
                                htm.WriteLine("</tr>");
                            }
                        }

                        //read data from datafile

                        if (!(datafile == ""))
                        {
                            string[] lines = File.ReadAllLines(datafile);


                            for (int a = lines.Length - 2; a >= 0; a--)
                            {
                                string[] daten = lines[a].Split(';');

                                //write old data in html-File
                                htm.WriteLine("<tr>");
                                htm.WriteLine("<td>" + daten[0] + "</td");
                                htm.WriteLine("<td align=\"right\">" + daten[1] + "</td>");
                                htm.WriteLine("<td align=\"right\">" + daten[2] + " (seit " + daten[3] + ")" + "</td>");
                                htm.WriteLine("</tr>");
                            }
                        }

                        // finish html-file
                        htm.WriteLine("</table>");
                        htm.WriteLine("</BODY>");
                        htm.WriteLine("</HTML>");

                        htm.Close();

                    }
                    

                }
                catch (COMException comExc)
                {

                    Console.WriteLine(comExc.ToString());


                }
                catch (Exception exc)
                {

                    Console.WriteLine(exc.ToString());

                }
            }
            Console.ReadKey();
        }

        private static void usage()
        {
            Console.WriteLine("Usage: pubstats [-p publishingpoint] [-d path to datafile]  [-h path to htmfile] [/?]");
            Console.WriteLine("Defaults: datafile: none, htmlfile: stats.htm, publishingpoint: Beispielpublishingpoint");

        }

    }
}
